@@ -1,7 +1,7 @@
 from .account import Account
 from .account_info import QiwiAccountInfo
 from .balance import Balance
-from .bill import Bill, BillError, RefundBill
+from .bill import Bill, BillError, RefundBill, Notification
 from .identification import Identification
 from .limit import Limit
 from .partner import Partner
@@ -11,6 +11,7 @@ from .qiwi_master import OrderDetails
 from .stats import Statistic
 from .terminal import Terminal
 from .transaction import Transaction
+from .webhooks import WebHookConfig, WebHook
 
 __all__ = (
     'QiwiAccountInfo',
@@ -27,5 +28,8 @@ __all__ = (
     'RefundBill',
     'Polygon',
     'Terminal',
-    'Partner'
+    'Partner',
+    'WebHook',
+    'WebHookConfig',
+    'Notification'
 )
